import { DeleteCommandInput, GetCommandInput, PutCommandInput, QueryCommandInput, ScanCommandInput } from '@aws-sdk/lib-dynamodb';
import { ConditionExpressionPredicate } from '@aws/dynamodb-expressions';
import { IndexName, Storage } from './storage';
import { IPageToken } from './page-token';
export interface KeyConfig {
    keys: string[];
    delimiter: string;
}
export declare type KeyFactory<T> = (entity: T) => string | undefined;
export declare type KeyDefinition<T> = string | string[] | KeyConfig | KeyFactory<T>;
export interface IIndexDefinition<T> {
    hash: KeyDefinition<T>;
    sort?: KeyDefinition<T>;
}
export interface IKeyGenerator<T> {
    hash: KeyFactory<T>;
    sort?: KeyFactory<T>;
}
export declare type ISchemaDefinition<T> = Record<IndexName, IIndexDefinition<T>>;
export interface IRepositoryParams<T> {
    storage: Storage;
    schema: Partial<ISchemaDefinition<T>>;
}
export interface IQueryParams {
    limit: number;
    indexName: IndexName;
    hash: string | number;
    sort?: string | number | ConditionExpressionPredicate;
    startKey?: IPageToken;
}
export interface IScanParams {
    indexName?: IndexName;
    startKey?: IPageToken;
    limit: number;
}
export declare class Schema<T> {
    storage: Storage;
    schema: Partial<Record<IndexName, IKeyGenerator<T>>>;
    constructor(params: IRepositoryParams<T>);
    indexData(entity: Partial<T>, indexName?: IndexName): {};
    putParams(entity: T): PutCommandInput;
    getParams(keyParams: Partial<T>): GetCommandInput;
    deleteParams(keyParams: Partial<T>): DeleteCommandInput;
    queryParams({ indexName, hash, sort, startKey, limit, }: IQueryParams): QueryCommandInput;
    scanParams({ indexName, startKey, limit }: IScanParams): ScanCommandInput;
}
